@@ -2,6 +2,9 @@
 
 use crate::model::{Cloud, Framework, Language, Process, Runtime, ServiceNode, System, User};
 
+/// Name for the trace id field, if one needs to be supplied manually.
+pub const TRACE_ID_FIELD_NAME: &str = "trace_id";
+
 pub struct Service {
     pub(crate) version: Option<String>,
     pub(crate) environment: Option<String>,
@@ -42,7 +45,7 @@ impl ApiKey {
     }
 }
 
-// APM authorization method.
+/// APM authorization method.
 pub enum Authorization {
     SecretToken(String),
     ApiKey(ApiKey),
@@ -58,6 +61,7 @@ pub struct Config {
     pub(crate) user: Option<User>,
     pub(crate) cloud: Option<Cloud>,
     pub(crate) allow_invalid_certs: bool,
+    pub(crate) root_cert_path: Option<String>,
 }
 
 impl Config {
@@ -73,6 +77,11 @@ impl Config {
         self
     }
 
+    pub fn with_root_cert_path(mut self, cert_path: String) -> Self {
+        self.root_cert_path = Some(cert_path);
+        self
+    }
+
     pub fn with_authorization(mut self, authorization: Authorization) -> Self {
         self.authorization = Some(authorization);
         self
